@@ -13,7 +13,8 @@ else:
 from navsy.exceptions import NoReverseMatch
 
 
-NAVSY_MULTILANGUAGE = bool(len(settings.LANGUAGES) > 1)
+NAVSY_LANGUAGES = settings.LANGUAGES
+NAVSY_MULTILANGUAGE = bool(len(NAVSY_LANGUAGES) > 1)
 NAVSY_USE_MODELTRANSLATION = False
 
 if NAVSY_MULTILANGUAGE and 'modeltranslation' in settings.INSTALLED_APPS:
