@@ -9,6 +9,8 @@ if settings.NAVSY_MULTILANGUAGE:
     from modeltranslation.translator import translator, TranslationOptions
 
     class PageTranslationOptions(TranslationOptions):
-        fields = ('name', 'slug', )
+        fields = (
+            'name', 'slug',
+            'seo_title', 'seo_description', 'seo_keywords', )
 
     translator.register(Page, PageTranslationOptions)
